@@ -20,13 +20,14 @@
 #ifndef GRAPHPLUGIN_H
 #define GRAPHPLUGIN_H
 
-#include <QDeclarativeExtensionPlugin>
+#include <QQmlExtensionPlugin>
 
-class ChartPlugin : public QDeclarativeExtensionPlugin
+class ChartPlugin : public QQmlExtensionPlugin
 {
     Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 public:
-    void registerTypes(const char *uri);
+    void registerTypes(const char *uri) override;
 };
 
 #endif // GRAPHPLUGIN_H
